navigation library

Classes

Alert
A navigation type that presents a system alert dialog.
AlertButton
AnalyticsIdentifiable
A class that contains the analytics information for ViewNavigationType.
Dismiss
A navigation type that dismisses the current view.
FeatureProvider
FeatureRoute
A navigation type for showing modal bottom sheets as screens.
A navigation analytics event.
A sink for navigation analytics events.
Describes one branch (tab) in a tabbed navigation shell.
A configuration for the navigation system.
A controller for managing the navigation stack.
A helper class for generating unique navigation keys.
A navigation analytics event emitted when a screen is entered.
A navigation analytics event emitted when a screen is exited.
Makes a NavigationThemeData available to descendant navigation pages.
Colors used by navigation-presented UI (alerts, modal bottom sheets).
NoAnimationPage<T>
NoPageViewNavigationType
Base class for all navigation types that do not modify the navigation stack because is managed by something else outside of the navigation system but still needs to be tracked for analytics and breadcrumbs.
PopTo
Pops back to the first occurrence of screenName when searching from the top of the stack (last to first).
Present
A navigation type that presents a new view on top of the current view.
PresentMultiple
A navigation type that presents a new view on top of the current view.
Push
A navigation type that pushes a new view onto the navigation stack.
PushMultiple
ReplaceAnimationType
ReplaceAnimationTypeCustom
ReplaceAnimationTypeNone
ReplaceAnimationTypePresent
ReplaceAnimationTypePush
ReplaceStack
ReplaceTop
SamePageNavigationCustomReplace
SamePageNavigationNoReplace
SamePageNavigationReplaceTop
SamePageNavigationReplaceType
Swipe
A navigation type that pushes a new view onto the navigation stack.
SwitchTab
Switches the active navigation branch (tab).
ViewNavigationType
Base class for all navigation types that use a widget builder.

Enums

PresentTransition
Controls the visual transition used when presenting a page.

Typedefs

Opaque identity for a navigation branch (tab).
Builds the shell (e.g. a bottom navigation bar) around the branch content swap widget.
RouteConfig = ({String? branchScreenName, Object navigationType, List<String> requiredPriorNavigation})