Alert class final

A navigation type that presents a system alert dialog.

Inheritance

Constructors

Alert({required String title, required List<AlertButton> buttons, required String analyticsScreenName, String? description, bool barrierDismissible = true, bool skipKeyboardDismissal = false, ValueKey<String>? navigationKey})

Properties

analyticsIdentifiable AnalyticsIdentifiable
finalinherited
analyticsName String
Stable identifier for analytics and breadcrumbs.
no setteroverride
animated bool
finalinherited
barrierDismissible bool
final
builder WidgetBuilder
no setterinherited
buttons List<AlertButton>
final
description String?
final
hashCode int
The hash code for this object.
no setterinherited
key ValueKey<String>
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenName String
no setterinherited
skipKeyboardDismissal bool
If true, the keyboard dismissal will be skipped before the navigation.
finalinherited
title String
final

Methods

buildAnimatedPage(BuildContext context) Page
override
buildPage(BuildContext context) Page
inherited
Modifies the navigation stack based on the current stack and the new navigation type.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited