AnalyticsIdentifiable class final
A class that contains the analytics information for ViewNavigationType.
Constructors
- AnalyticsIdentifiable({required String screenName, required WidgetBuilder builder, String dynamicScreenName()?})
-
const
- AnalyticsIdentifiable.withDynamicScreenName(String screenName(), {required WidgetBuilder builder})
-
factory
Properties
- builder → WidgetBuilder
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- screenName → String
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited