Dismiss class final

A navigation type that dismisses the current view.

When the dismissed view is a presented screen awaited via NavigationController.present<T>, pass result to resolve that future with a value — the idiomatic, action-based equivalent of Navigator.pop(context, result).

Inheritance

Constructors

Dismiss({Object? result, bool skipKeyboardDismissal = false})
const

Properties

analyticsName String
Stable identifier for analytics and breadcrumbs.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
result Object?
The value to resolve an in-flight present<T> with, if the dismissed view is a presented screen. null (the default) resolves with null.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skipKeyboardDismissal bool
If true, the keyboard dismissal will be skipped before the navigation.
final

Methods

Modifies the navigation stack based on the current stack and the new navigation type.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited