wantsKeepAlive property
When true (default), the branch's widget subtree is kept alive while
off-stage. When false, it is disposed and rebuilt on return.
Implementation
final bool wantsKeepAlive;
When true (default), the branch's widget subtree is kept alive while
off-stage. When false, it is disposed and rebuilt on return.
final bool wantsKeepAlive;