shellBuilder property
Builds the shell (e.g. bottom navigation bar) around the branch content swap when the controller is tabbed. Ignored for single-stack controllers.
Implementation
final NavigationShellBuilder? shellBuilder;
Builds the shell (e.g. bottom navigation bar) around the branch content swap when the controller is tabbed. Ignored for single-stack controllers.
final NavigationShellBuilder? shellBuilder;