NavigationKey class

A helper class for generating unique navigation keys.

This class provides a way to generate stable, unique keys for navigation pages that can be used both when creating the page and within the page's view model for registering callbacks.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

generate(String screenName) ValueKey<String>
Generates a unique key for a navigation page.