NavigationScreenExitEvent class
A navigation analytics event emitted when a screen is exited.
Emitted to a NavigationAnalyticsSink when one is provided to the
navigation controller.
- Implemented types
Constructors
-
const
Properties
- destinationScreen → String?
-
The screen the user navigated to.
final
- exitMethod → String?
-
The method used to exit (dismiss, pop, replace, etc.).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- screenName → String
-
The name of the screen being exited.
final
- timeSpent → int?
-
Time spent on the screen in seconds, if tracked.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited