NavigationType class abstract base

Implementers

Constructors

const

Properties

analyticsName String
Stable identifier for analytics and breadcrumbs.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skipKeyboardDismissal bool
If true, the keyboard dismissal will be skipped before the navigation.
no setter

Methods

Modifies the navigation stack based on the current stack and the new navigation type.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited