navigationStackFrom abstract method
Modifies the navigation stack based on the current stack and the new navigation type.
Implementation
List<ViewNavigationType> navigationStackFrom(
List<ViewNavigationType> currentStack,
);
Modifies the navigation stack based on the current stack and the new navigation type.
List<ViewNavigationType> navigationStackFrom(
List<ViewNavigationType> currentStack,
);