skipKeyboardDismissal property
If true, the keyboard dismissal will be skipped before the navigation.
Implementation
bool get skipKeyboardDismissal;
If true, the keyboard dismissal will be skipped before the navigation.
bool get skipKeyboardDismissal;