PresentMultiple class final

A navigation type that presents a new view on top of the current view.

Inheritance

Constructors

PresentMultiple({required AnalyticsIdentifiable analyticsIdentifiable, required List<ViewNavigationType> hiddenPages, bool animated = true, ValueKey<String>? navigationKey, bool skipKeyboardDismissal = false})

Properties

analyticsIdentifiable AnalyticsIdentifiable
finalinherited
analyticsName String
Stable identifier for analytics and breadcrumbs.
no setteroverride
animated bool
finalinherited
builder WidgetBuilder
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hiddenPages List<ViewNavigationType>
final
key ValueKey<String>
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenName String
no setterinherited
skipKeyboardDismissal bool
If true, the keyboard dismissal will be skipped before the navigation.
finalinherited

Methods

buildAnimatedPage(BuildContext context) Page
override
buildPage(BuildContext context) Page
inherited
Modifies the navigation stack based on the current stack and the new navigation type.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited