ReplaceAnimationTypeCustom class final

Inheritance

Constructors

ReplaceAnimationTypeCustom({required ViewNavigationType handler(AnalyticsIdentifiable analyticsIdentifiable, ValueKey<String> key, {required bool animated}), required bool swipeToDismissEnabled, bool animated = true})
const

Properties

animated bool
finalinherited
handler ViewNavigationType Function(AnalyticsIdentifiable analyticsIdentifiable, ValueKey<String> key, {required bool animated})
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
swipeToDismissEnabled bool
final

Methods

override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited