Swipe class final

A navigation type that pushes a new view onto the navigation stack.

Inheritance

Constructors

Swipe({required AnalyticsIdentifiable analyticsIdentifiable})

Properties

analyticsName String
Stable identifier for analytics and breadcrumbs.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
key ValueKey<String>
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenName String
no setterinherited
skipKeyboardDismissal bool
If true, the keyboard dismissal will be skipped before the navigation.
no setteroverride

Methods

Modifies the navigation stack based on the current stack and the new navigation type.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited