ViewNavigationType class abstract base

Base class for all navigation types that use a widget builder.

Inheritance
Mixed-in types
Implementers

Constructors

ViewNavigationType({required AnalyticsIdentifiable analyticsIdentifiable, ValueKey<String>? navigationKey, bool skipKeyboardDismissal = false, bool animated = true})

Properties

analyticsIdentifiable AnalyticsIdentifiable
final
analyticsName String
Stable identifier for analytics and breadcrumbs.
no setterinherited
animated bool
final
builder WidgetBuilder
no setter
hashCode int
The hash code for this object.
no setterinherited
key ValueKey<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenName String
no setteroverride
skipKeyboardDismissal bool
If true, the keyboard dismissal will be skipped before the navigation.
final

Methods

buildAnimatedPage(BuildContext context) Page
buildPage(BuildContext context) Page
Modifies the navigation stack based on the current stack and the new navigation type.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited