NavigationRouterDelegate class final

A router delegate for managing the navigation stack.

Inheritance
Mixed-in types

Constructors

Properties

currentConfiguration RouteConfig?
Current route configuration, reported to the Router so the browser address bar reflects navigation on web.
no setteroverride
currentNavigatorKey GlobalKey<NavigatorState>
The key of the Navigator currently on stage.
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
The key used for retrieving the current navigator.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shellBuilder NavigationShellBuilder?
final

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
build(BuildContext context) Widget
Called by the Router to obtain the widget tree that represents the current state.
override
dispose() → void
Discards any resources used by the object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
popRoute() Future<bool>
Called by the Router when the Router.backButtonDispatcher reports that the operating system is requesting that the current route be popped.
override
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
setInitialRoutePath(Object configuration) Future<void>
Called by the Router at startup with the structure that the RouteInformationParser obtained from parsing the initial route.
inherited
setNewRoutePath(Object configuration) Future<void>
Called by the Router when the Router.routeInformationProvider reports that a new route has been pushed to the application by the operating system.
override
setRestoredRoutePath(Object configuration) Future<void>
Called by the Router during state restoration.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited