setNewRoutePath method

  1. @override
Future<void> setNewRoutePath(
  1. Object configuration
)
override

Called by the Router when the Router.routeInformationProvider reports that a new route has been pushed to the application by the operating system.

Consider using a SynchronousFuture if the result can be computed synchronously, so that the Router does not need to wait for the next microtask to schedule a build.

Implementation

@override
Future<void> setNewRoutePath(Object configuration) async {
  if (configuration is! RouteConfig) return;
  if (configuration.navigationType is! NavigationType) return;
  final routeConfig = configuration;

  if (_canApplyRouteConfig(routeConfig)) {
    _applyRouteConfig(routeConfig);

    return;
  }

  _pendingRouteConfig = routeConfig;
  _tryResolvePendingDeepLink();
}