ScreenTimeTracker class final
Tracks time spent on screens for analytics.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clear(
) → void - Clears all tracked screen times (useful for testing).
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
recordScreenEnter(
String screenName) → void - Records when a screen was entered.
-
recordScreenExit(
String screenName) → int? - Records when a screen was exited and returns time spent in seconds.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited