AlertButton class final
- Annotations
Constructors
- AlertButton({required String title, VoidCallback? onPressed, bool dismissAlert = true, bool isDestructive = false, bool isDefault = false})
-
const
Properties
- dismissAlert → bool
-
If true, the alert will be dismissed before calling onPressed.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDefault → bool
-
iOS only: marks the action as the default action.
final
- isDestructive → bool
-
iOS only: marks the action as destructive.
final
- onPressed → VoidCallback?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- cancel → const AlertButton