NavigationConfig class final
A configuration for the navigation system.
- Inheritance
-
- Object
- RouterConfig<
Object> - NavigationConfig
Constructors
Properties
- backButtonDispatcher → BackButtonDispatcher?
-
The BackButtonDispatcher that is used to configure the Router.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
routeInformationParser
→ RouteInformationParser<
Object> ? -
The RouteInformationParser that is used to configure the Router.
finalinherited
- routeInformationProvider → RouteInformationProvider?
-
The RouteInformationProvider that is used to configure the Router.
finalinherited
-
routerDelegate
→ RouterDelegate<
Object> -
The RouterDelegate that is used to configure the Router.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shellBuilder → NavigationShellBuilder?
-
Builds the shell (e.g. bottom navigation bar) around the branch content
swap when the controller is tabbed. Ignored for single-stack controllers.
final
- theme → NavigationThemeData?
-
Theme applied to navigation-presented UI (dialogs, bottom sheets).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited