NavigationScreenEnterEvent class
A navigation analytics event emitted when a screen is entered.
Emitted to a NavigationAnalyticsSink when one is provided to the
navigation controller.
- Implemented types
Constructors
-
const
Properties
-
The breadcrumb trail of the navigation at enter time.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
The navigation method that triggered the enter (push, present,
replace, etc.).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- screenName → String
-
The name of the screen being entered.
final
- sourceScreen → String?
-
The screen the user navigated from.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited