Base class for all navigation types that do not modify the navigation stack because is managed by something else outside of the navigation system but still needs to be tracked for analytics and breadcrumbs.
- Inheritance
-
- Object
- NavigationType
- NoPageViewNavigationType
- Mixed-in types
- Implementers
Constructors
Properties
- analyticsName → String
-
Stable identifier for analytics and breadcrumbs.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
key
→ ValueKey<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- screenName → String
-
no setteroverride
- skipKeyboardDismissal → bool
-
If true, the keyboard dismissal will be skipped before the navigation.
no setterinherited
Methods
-
Modifies the navigation stack based on the current stack
and the new navigation type.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited