PopTo class final
Pops back to the first occurrence of screenName when searching from the top of the stack (last to first).
If no page with screenName exists, this action is a no-op.
- Inheritance
-
- Object
- NavigationType
- PopTo
- Mixed-in types
Properties
- analyticsName → String
-
Stable identifier for analytics and breadcrumbs.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- screenName → String
-
final
- skipKeyboardDismissal → bool
-
If true, the keyboard dismissal will be skipped before the navigation.
final
Methods
-
Modifies the navigation stack based on the current stack
and the new navigation type.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited