Present class final

A navigation type that presents a new view on top of the current view.

A presented screen can return a result by calling Navigator.pop(context, result). Await NavigationController.present (or dismissed) to receive it. dismissed requires animated (the default); a non-animated presentation does not wire a result.

Inheritance

Constructors

Present({required AnalyticsIdentifiable analyticsIdentifiable, bool animated = true, ValueKey<String>? navigationKey, PresentTransition transition = .standard, bool skipKeyboardDismissal = false})

Properties

analyticsIdentifiable AnalyticsIdentifiable
finalinherited
analyticsName String
Stable identifier for analytics and breadcrumbs.
no setteroverride
animated bool
finalinherited
builder WidgetBuilder
no setterinherited
dismissed Future<Object?>
Completes with the result the presented screen was dismissed with.
no setter
hashCode int
The hash code for this object.
no setterinherited
key ValueKey<String>
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenName String
no setterinherited
skipKeyboardDismissal bool
If true, the keyboard dismissal will be skipped before the navigation.
finalinherited
transition PresentTransition
The visual transition style for this presentation.
final

Methods

buildAnimatedPage(BuildContext context) Page<Object?>
override
buildPage(BuildContext context) Page
inherited
completeWith(Object? result) → void
Completes dismissed with result if it has not already completed.
Modifies the navigation stack based on the current stack and the new navigation type.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited