dismissed property
Completes with the result the presented screen was dismissed with.
Resolves with the Dismiss.result when a Dismiss(result: ...) action
dismisses this screen, with the value passed to Navigator.pop when the
screen pops itself, or with null on a bare programmatic dismiss.
Prefer NavigationController.present for a typed result.
Implementation
Future<Object?> get dismissed => _dismissedCompleter.future;