AnalyticsQueue class final
A background queue for processing navigation analytics events to prevent UI blocking.
Events are NavigationAnalyticsEvents (screen-enter or screen-exit). They are forwarded to the provided NavigationAnalyticsSink after the current frame is painted.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
enqueue(
NavigationAnalyticsEvent event) → void -
Queues a navigation analytics event for background processing. The queue
dispatches enter/exit events to the sink's
onScreenEnter/onScreenExit. -
flush(
) → Future< void> - Flushes all remaining events through the sink and shuts down the queue.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited